#include "Player.hpp"
#include "ui_Player.h"
#include <qdatetime.h>
#include <qglobal.h>
#include <qmediaplayer.h>
#include <qnetworkreply.h>
#include <qurl.h>
#include <QStyle>
#include <QTimer>
#include <string>
#include <QNetworkAccessManager>
#include <QNetworkReply>
#include <QNetworkRequest>
#include <sys/socket.h>

Player::Player(QMediaPlayer *audioPlayer, QWidget *parent) :
    QWidget(parent),
    audioPlayer(audioPlayer),
    ui(new Ui::Player)
{
    ui->setupUi(this);
    if (!audioPlayer) {
        qDebug() << "Svoi";
        audioPlayer = new QMediaPlayer(this);
    }
    ui->playButton->setEnabled(false);
    ui->playButton->setIcon(style()->standardIcon(QStyle::SP_MediaPlay));
    connect(audioPlayer, &QMediaPlayer::stateChanged, 
            this, &Player::onStateChanged);
    connect(audioPlayer, &QMediaPlayer::mediaStatusChanged, 
            this, &Player::onStatusChanged);
}

Player::~Player()
{
    delete ui;
}

void Player::set(SourceWithAdditionalInfo audio, bool isLocal) {
    qDebug() << "here";
    if (isLocal) {
        url = QUrl::fromLocalFile(QString::fromStdString(audio.src));
        return;
    }
    url = QUrl(QString::fromStdString(audio.src));
    ui->infoEdit->setText(QString::fromStdString(audio.info));
    ui->playButton->setEnabled(true);
    ui->infoEdit->setEnabled(false);
}

void Player::onStateChanged(QMediaPlayer::State state) {
    if (state == QMediaPlayer::StoppedState) {
        ui->playButton->setEnabled(true);
    }
}

void Player::onStatusChanged(QMediaPlayer::MediaStatus status) {
    if (status == QMediaPlayer::LoadedMedia) {
        ui->playButton->setEnabled(true);
    }
}

void Player::onPlayClicked() {
    audioPlayer->setMedia(url);
    audioPlayer->play();
    ui->playButton->setEnabled(false);
}
